@@ -1,9 +1,9 @@
 use crate::filter::{Filter, Next};
-use crate::{Request, Response, Result, Error};
+use crate::{Error, Request, Response, Result};
 use async_trait::async_trait;
 
-use tracing::{debug, error, warn, info};
 use crate::state::State;
+use tracing::{debug, error, info, warn};
 
 /// A logging filter. Logs all requests at debug level, and logs responses at error, warn or info
 /// level depending on the status code (5xx, 4xx, and everything else)
@@ -21,8 +21,7 @@ fn log_response(method: String, uri: String, resp: &Response) {
 }
 
 #[async_trait]
-impl<S: State> Filter<S> for Log
-{
+impl<S: State> Filter<S> for Log {
     async fn apply(&self, req: Request<S>, next: Next<'_, S>) -> Result<Response> {
         let method = req.method().to_string();
         let uri = req.uri().to_string();
